#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-9Szrt1jMHPS272hiipCg6a
key:                  dhall-1.42.3-9Szrt1jMHPS272hiipCg6a
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  fb705e77fa4a53ae4e482e05e5385970
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-9Szrt1jMHPS272hiipCg6a
depends:
    Diff-0.5-Am7LKUlc3753Bz8cDMWPBf
    aeson-2.2.1.0-FEnGzvKMunxDwDFhBeJYHO
    aeson-pretty-0.8.10-Ivax4iYwu8KFWXwjiRmlk4
    ansi-terminal-1.1-4Fc3pfbWuzJIdO3EFXFaIS
    atomic-write-0.2.1.1-EyPOJhe5795Dx9HjH2vye1 base-4.18.2.1
    base16-bytestring-1.0.2.0-BrKum4UJoGp9BOvJ2feb26
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-DkQB71KJg2v82iYJB6vXcb
    cborg-0.2.10.0-2Vr08EdLV3XF6ktNtUznSG
    cborg-json-0.2.6.0-B7AIGidzTdG6ZvYHV2ANPk containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-JS5IWqS1DJV2TerpupO7at
    data-fix-0.3.4-ArfbrRaQZCt2YhKpTMJAcN deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-1451njYkzzF6nCyJ1Kdnir exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-4QLfPblL6nAEFUoN9G49M2
    hashable-1.4.7.0-H7NkROSKCrjFQZGpvHIgO1 haskeline-0.8.2.1
    http-client-0.7.19-KIsPCwAmJfj40FXZ7rXqbo
    http-client-tls-0.3.6.4-Doual9R7PJYKTahqZ4qgD9
    http-types-0.12.4-5BZtRmLQcWTCOOFKM75zCu
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-9f5jmYCwU8WCdqBa8mE3Wb
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-91j990LrivP71ivMfH7l0g
    optparse-applicative-0.18.1.0-JYwGc1030kp1M9C8Y9ZIot
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-AHBbX7OR1dbCVyeihKL5eB
    pretty-simple-4.1.4.0-CbJFtiBxwN16AEXObVQB33
    prettyprinter-1.7.1-SaqeLf0VF75CcRG6tvr9r
    prettyprinter-ansi-terminal-1.1.3-AtzM4takVDM8qT5kzuvjEH
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-AGaiR8m7w2Z7AlSJwhzWHa
    serialise-0.2.6.1-4g2aY8TFT1JDclUe180xFI template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-FzaVJi4RfrVCF9XyuUQbBR
    text-short-0.1.6.1-6ACgqGQI0oo4iT36ndHzFP
    th-lift-instances-0.1.20-K4GcOG7SmfH1Bpjcqma1J time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-CNHdcuBo4WyE8NnkOFSrdm
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V
    vector-0.13.2.0-BkeaBlIIAt9GprLstCadki

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

